============
*pypathutil*
============

.. image:: https://img.shields.io/pypi/v/pypathutil

.. image:: https://img.shields.io/github/license/veltzer/pypathutil

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pypathutil

author: Mark Veltzer

version: 0.0.17

	Mark Veltzer <mark.veltzer@gmail.com>, Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024
